/**
 * Svelte action to initialize Semantic UI `Popup` component.
 * @module components/use-popup
 */
import { jQueryElem } from "../data/dom-jquery";
/** Svelte action to initialize Semantic UI `Popup` component.

https://semantic-ui.com/modules/popup.html

Supply popup parameters using a settings object or through data-* attributes.
```
    <input type="text" bind:value={name2}
        use:popup={{
            content: "Please enter given name",
            position: "bottom right"
        }}
    >
```
*/
export function popup(node, settings) {
    const elem = jQueryElem(node);
    if (!elem.popup) {
        throw new Error("Semantic popup is not initialized");
    }
    elem.popup({
        ...settings,
    });
    return {
        update(newSettings) {
            elem.popup("destroy");
            elem.popup(newSettings);
        },
        destroy() {
            elem.popup("destroy");
        },
    };
}
