/**
 * Svelte action to initialize Semantic UI `Sticky` component.
 * @module components/use-sticky
 */
import { jQueryElem } from "../data/dom-jquery";
/** Svelte action to initialize Semantic UI `Sticky` component.

https://fomantic-ui.com/modules/sticky.html

By default attaches itself to the parent component.
```
    <div class="ui right rail">
        <div class="ui segment sticky" use:sticky={{ offset: 10 }}>
            <div class="ui message">...</div>
            <button class="ui button red" on:click={reset}>Reset</button>
        </div>
    </div>
```
*/
export function sticky(node, settings) {
    const elem = jQueryElem(node);
    if (!elem.sticky) {
        throw new Error("Semantic sticky is not initialized");
    }
    elem.sticky({
        ...settings,
    });
    return {
        update(newSettings) {
            elem.sticky(newSettings);
        },
    };
}
