/**
 * Common types, utility functions.
 * @module data/common
 */
/** Settings controlling number and money formatting. */
export interface NumberSettings {
    decimalSeparator: string;
    thousandSeparator: string;
    moneyPrefix: string;
    moneySuffix: string;
    moneyPrecision: number;
}
/** Settings used to initialize a number input component: number settings, type, and precision */
export interface NumberInputSettings extends Partial<NumberSettings> {
    type?: "integer" | "decimal" | "money";
    precision?: number;
}
/** Settings used to initialize a text input component */
export type TextInputSettings = {
    case?: "upper" | "lower" | "title" | "none";
    charset?: "any" | "euro" | "latin" | "ascii" | "id_alpha" | "id_hex" | "id_num";
    idAllowChars?: Array<"_" | "-" | ".">;
    idBlockChars?: Array<"I" | "O" | "i" | "o" | "l">;
    blockSingleQuotes?: boolean;
    blockDoubleQuotes?: boolean;
    allowHtmlTags?: boolean;
    blockEmoji?: boolean;
    /** Maximum value length. Intended for "id_*" charset, in other cases it is often better to use validation */
    maxLen?: number;
    /** The input returns string[] */
    list?: boolean;
    /** Character user to separate values */
    listSeparator?: string;
};
/** Compare two Date objects */
export declare function equalDates(a1: Date | undefined, a2: Date | undefined): boolean;
/** Compare two string arrays or strings */
export declare function equalStringArrays(a1: string[] | string | undefined, a2: string[] | string | undefined): boolean;
/** Compare two number arrays or numbers */
export declare function equalNumberArrays(a1: number[] | number | undefined, a2: number[] | number | undefined): boolean;
/** Format a number, padded with "0" to the minimum length */
export declare function pad(n: number, size: number): string;
/** Format Date using YYYY-MM-DD format */
export declare function isoDate(d: Date | undefined): string;
/** Format Date as time using HH:mm format (24 hours) */
export declare function isoTime(d: Date | undefined): string;
/** Convert objects to JSON string, for jQuery and DOM elements - get the HTML */
export declare function stringify(obj: unknown): string;
export type LogLevel = "error" | "warn" | "log" | "info" | "debug";
type LogFunction = (...args: unknown[]) => void;
type LogImplFunction = (level: LogLevel, ...args: unknown[]) => void;
export declare class Logger {
    prefix: string;
    error: LogFunction;
    warn: LogFunction;
    log: LogFunction;
    info: LogFunction;
    debug: LogFunction;
    private LOG_LEVELS;
    private loglevelToNumber;
    constructor(prefix: string);
    build(level: LogLevel | "off", fn?: LogImplFunction): void;
}
export declare function buildHttpLogger(logger: Logger, level: LogLevel | "off", url: string): void;
export declare const formLog: Logger;
export declare const compLog: Logger;
export declare const initLog: Logger;
export {};
