/**
 * Svelte field validation controller, used by all Init Svelte components.
 * @module data/field-controller
 */
import type { JQueryApi, RuleDefinition } from "../data/semantic-types";
import type { FormController } from "../data/form-controller";
export type FieldType = "calendar" | "dropdown" | "slider" | "checkbox" | "input";
/** Adds validation rule to the field.
 *  Common class used by all Init* components to control field validation */
export declare class FieldController {
    /** Field key used for form validation, is initialized for all fields. */
    key: string;
    type: FieldType;
    /** Optional reference to form controlled, is initialized only if the field has validation rules. */
    formCtrl?: FormController;
    /** Field validation rules */
    rules?: RuleDefinition;
    /** Create ne field controller for the input. If it is validated, find and store form controller */
    constructor(type: FieldType, input: JQueryApi, validationRules?: RuleDefinition);
    /** Update filed validation rules if they are changed at runtime */
    replaceRules(validationRules?: RuleDefinition): void;
    /** Validate the new field value, if the field is validated (has form controller).
     *  This method is `async` as it debounces (deduplicates) the validation event
     *  in case multiple fields are modified in a single Svelte 'tick'. */
    revalidate(): Promise<void>;
    /** Remove rules and revalidate */
    removeRules(): void;
}
