/**
 * DateFormatter object, is initialized using a portion of CalendarSettings.
 * @module data/input-formatter
 */
import { calendarDefaults } from "./settings";
import { helperDateFormat } from "./semantic-date-format";
/** DateFormatter implementation which uses a copy of FomanticCalendar code */
export class DateFmt {
    constructor(settings = {}) {
        const def = calendarDefaults.read();
        /* eslint-disable key-spacing, no-multi-spaces */
        /* prettier-ignore */
        this.settings = {
            // settings which are used for format() and parse()
            type: settings.type ?? def.type,
            monthFirst: settings.monthFirst ?? def.monthFirst,
            firstDayOfWeek: settings.firstDayOfWeek ?? def.firstDayOfWeek,
            centuryBreak: settings.centuryBreak ?? def.centuryBreak,
            currentCentury: settings.currentCentury ?? def.currentCentury,
            parser: {
                date: settings.parser?.date ?? def.parser?.date,
            },
            formatter: {
                date: settings.formatter?.date ?? def.formatter?.date,
                datetime: settings.formatter?.datetime ?? def.formatter?.datetime,
                time: settings.formatter?.time ?? def.formatter?.time,
            },
            // deep-copy sub-objects
            text: { ...def.text, ...settings.text },
            regExp: { ...def.regExp, ...settings.regExp },
        };
        /* eslint-enable */
    }
    parse(val) {
        if (!val) {
            return undefined;
        }
        const dateParser = this.settings.parser.date;
        return dateParser(val, this.settings) ?? undefined;
    }
    format(val) {
        if (val === undefined || val === null) {
            return "";
        }
        if (!(val instanceof Date)) {
            throw new Error(`dateFormatter expects Date as data type, got ${typeof val} = ${val}`);
        }
        const formatter = this.settings.formatter;
        const type = this.settings.type;
        const formatStrOrFunc = formatter[type];
        return helperDateFormat(formatStrOrFunc, val, this.settings);
    }
}
