/**
 * Global `fmt` and `parse` objects with default formatting settings, autocomplete helper for validation rules.
 * @module data/helpers
 */
/** Default formatter helper. Intended to be used from code of svelte components:
 * ```
 * Total: {fmt.money(value)}
 * ``` */
export declare const fmt: {
    date: (d: Date | undefined) => string;
    time: (d: Date | undefined) => string;
    int: (n: number | undefined) => string;
    num: (n: number | undefined) => string;
    num2: (n: number | undefined) => string;
    num6: (n: number | undefined) => string;
    money: (n: number | undefined) => string;
};
/** Default parser helper. Intended to be used from code. */
export declare const parse: {
    date: (s: string) => Date | undefined;
    time: (s: string) => Date | undefined;
    int: (s: string) => number | undefined;
    num: (s: string) => number | undefined;
    num2: (s: string) => number | undefined;
    num6: (s: string) => number | undefined;
    money: (s: string) => number | undefined;
};
/** Autocomplete helper for validation rules. */
export declare const rule: {
    empty: () => string;
    checked: () => string;
    email: () => string;
    url: () => string;
    integer: () => string;
    decimal: () => string;
    number: () => string;
    creditCard: () => string;
    regex: (reg: string) => string;
    is: (val: string) => string;
    isExactly: (val: string) => string;
    not: (val: string) => string;
    notExactly: (val: string) => string;
    contains: (val: string) => string;
    containsExactly: (val: string) => string;
    doesntContain: (val: string) => string;
    doesntContainExactly: (val: string) => string;
    match: (fld: string) => string;
    different: (fld: string) => string;
    minLength: (n: number) => string;
    exactLength: (n: number) => string;
    maxLength: (n: number) => string;
    minCount: (n: number) => string;
    exactCount: (n: number) => string;
    maxCount: (n: number) => string;
    start: (val: string) => string;
    isoDate: () => string;
    wrappedIn: (val: string) => string;
    range: (min: number, max: number) => string;
    size: (min: number, max: number) => string;
    maxValue: (val: Date | number | string) => string;
    minValue: (val: Date | number | string) => string;
};
